@@ -58,6 +58,21 @@ class Plugin(plugin.PluginBase):
         self._enable = False
         self._directory_name = None
 
+    # TODO: Fix to support also IPv6
+    _INET_ADDRESS_RE = re.compile(
+        flags=re.VERBOSE,
+        pattern=r"""
+            \s+
+            inet
+            \s
+            (?P<address>\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}/\d{1,2})
+            .+
+            \s+
+            (?P<interface>[a-zA-Z0-9_.]+)
+            $
+    """
+    )
+
     def _validate_ip_cidr(self, ipcidr):
         try:
             ip = netaddr.IPNetwork(ipcidr)
@@ -100,16 +115,26 @@ class Plugin(plugin.PluginBase):
                 device=device,
             )
         )
-        addresses = self._hostname_helper.getLocalAddresses(
-            exclude_loopback=True,
-            device=device
+        rc, stdout, stderr = self.execute(
+            args=(
+                self.command.get('ip'),
+                'addr',
+                'show',
+                device,
+            ),
         )
-        if not addresses:
+        address = None
+        for line in stdout:
+            addressmatch = self._INET_ADDRESS_RE.match(line)
+            if addressmatch is not None:
+                address = addressmatch.group('address')
+                break
+        self.logger.debug('address: ' + str(address))
+
+        if address is None:
             raise RuntimeError(
                 _('Cannot acquire nic/bridge address')
             )
-        address = addresses.pop()
-        self.logger.debug('address: ' + str(address))
         try:
             ipna = netaddr.IPNetwork(address)
         except netaddr.AddrFormatError:
@@ -886,13 +911,13 @@ class Plugin(plugin.PluginBase):
             if self.environment[
                 ohostedcons.CloudInit.VM_STATIC_CIDR
             ]:
+                fname = (
+                    '/etc/sysconfig/network-scripts/ifcfg-{iname}'.format(
+                        iname=_interface_name
+                    )
+                )
 
                 if self.environment[ohostedcons.CloudInit.VM_DNS]:
-                    fname = (
-                        '/etc/sysconfig/network-scripts/ifcfg-{iname}'.format(
-                            iname=_interface_name
-                        )
-                    )
                     dnslist = [
                         d.strip()
                         for d
@@ -917,6 +942,29 @@ class Plugin(plugin.PluginBase):
                             ],
                             f=fname,
                         )
+
+                # Due to another cloud-init bug we have now also to force
+                # the gataway address:
+                # https://bugs.launchpad.net/cloud-init/+bug/1686856
+                # https://bugzilla.redhat.com/show_bug.cgi?id=1492726
+                # TODO: remove ASAP once fixed on cloud-init side
+                if self.environment[ohostedcons.NetworkEnv.GATEWAY]:
+                    bootcmd += (
+                        ' - if ! grep -Gq "^GATEWAY" {f}; '
+                        'then echo "GATEWAY={g}" >> {f}; '
+                        'fi\n'
+                    ).format(
+                        g=self.environment[ohostedcons.NetworkEnv.GATEWAY],
+                        f=fname,
+                    )
+                    bootcmd += (
+                        ' - if ! grep -Gq "^DEFROUTE" {f}; '
+                        'then echo "DEFROUTE=yes" >> {f}; '
+                        'fi\n'
+                    ).format(
+                        f=fname,
+                    )
+
                 bootcmd += (
                     ' - ifdown {iname}\n'
                     ' - ifup {iname}\n'
